==> fullcalendar-ag4-0.1.0.tgz: package/index.js <==
import { Component, Directive, ElementRef, Injectable, Input, NgModule, Pipe } from '@angular/core';
import { CommonModule } from '@angular/common';
import * as jqueryProxy from 'jquery/index';
import jqueryProxy__default from 'jquery/index';
import 'fullcalendar/index';

var jquery = jqueryProxy__default || jqueryProxy;
var CalendarComponent = (function () {
    /**
     * @param {?} element
     */
    function CalendarComponent(element) {
        this.element = element;
    }
    /**
     * @return {?}
     */
    CalendarComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function () {
            jquery('calendar-component').fullCalendar(_this.options);
        }, 100);
    };
    /**
     * @param {...?} args
     * @return {?}
     */
    CalendarComponent.prototype.fullCalendar = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return jquery(this.element.nativeElement).fullCalendar(args[0]);
    };
    return CalendarComponent;
}());
CalendarComponent.decorators = [
    { type: Component, args: [{
                selector: 'calendar-component',
                template: '<div></div>'
            },] },
];
/**
 * @nocollapse
 */
CalendarComponent.ctorParameters = function () { return [
    { type: ElementRef, },
]; };
CalendarComponent.propDecorators = {
    'options': [{ type: Input },],
};

var SampleDirective = (function () {
    /**
     * @param {?} el
     */
    function SampleDirective(el) {
        this.el = el;
    }
    return SampleDirective;
}());
SampleDirective.decorators = [
    { type: Directive, args: [{
                selector: '[sampleDirective]'
            },] },
];
/**
 * @nocollapse
 */
SampleDirective.ctorParameters = function () { return [
    { type: ElementRef, },
]; };

/**
 * Transforms any input value
 */
var SamplePipe = (function () {
    function SamplePipe() {
    }
    /**
     * @param {?} value
     * @param {?=} args
     * @return {?}
     */
    SamplePipe.prototype.transform = function (value, args) {
        if (args === void 0) { args = null; }
        return value;
    };
    return SamplePipe;
}());
SamplePipe.decorators = [
    { type: Pipe, args: [{
                name: 'samplePipe'
            },] },
    { type: Injectable },
];
/**
 * @nocollapse
 */
SamplePipe.ctorParameters = function () { return []; };

var SampleService = (function () {
    function SampleService() {
    }
    return SampleService;
}());
SampleService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
SampleService.ctorParameters = function () { return []; };

var CalendarModule = (function () {
    function CalendarModule() {
    }
    /**
     * @return {?}
     */
    CalendarModule.forRoot = function () {
        return {
            ngModule: CalendarModule,
            providers: [SampleService]
        };
    };
    return CalendarModule;
}());
CalendarModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    CalendarComponent,
                    SampleDirective,
                    SamplePipe
                ],
                exports: [
                    CalendarComponent,
                    SampleDirective,
                    SamplePipe
                ]
            },] },
];
/**
 * @nocollapse
 */
CalendarModule.ctorParameters = function () { return []; };

export { CalendarModule, CalendarComponent, SampleDirective, SamplePipe, SampleService };

==> fullcalendar-ag4-0.1.3.tgz: package/index.js <==
import { Component, ElementRef, Input, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import * as jqueryProxy from 'jquery';
import jqueryProxy__default from 'jquery';
import 'fullcalendar';

var jquery = jqueryProxy__default || jqueryProxy;
var CalendarComponent = (function () {
    function CalendarComponent(element) {
        this.element = element;
    }
    CalendarComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function () {
            jquery('calendar-component').fullCalendar(_this.options);
        }, 100);
    };
    CalendarComponent.prototype.fullCalendar = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return jquery(this.element.nativeElement).fullCalendar(args[0]);
    };
    return CalendarComponent;
}());
CalendarComponent.decorators = [
    { type: Component, args: [{
                selector: 'calendar-component',
                template: '<div></div>'
            },] },
];
/** @nocollapse */
CalendarComponent.ctorParameters = function () { return [
    { type: ElementRef, },
]; };
CalendarComponent.propDecorators = {
    'options': [{ type: Input },],
};

var CalendarModule = (function () {
    function CalendarModule() {
    }
    CalendarModule.forRoot = function () {
        return {
            ngModule: CalendarModule
        };
    };
    return CalendarModule;
}());
CalendarModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    CalendarComponent
                ],
                exports: [
                    CalendarComponent
                ]
            },] },
];
/** @nocollapse */
CalendarModule.ctorParameters = function () { return []; };

export { CalendarModule, CalendarComponent };
